package com.op.wms.service;

import java.util.List;
import com.op.wms.domain.OdsWhiteEmbryoInventory;

/**
 * 白胚盘点单Service接口
 * 
 * @author Open Platform
 * @date 2023-07-06
 */
public interface IOdsWhiteEmbryoInventoryService {
	/**
	 * 查询白胚盘点单
	 * 
	 * @param ID 白胚盘点单主键
	 * @return 白胚盘点单
	 */
	public OdsWhiteEmbryoInventory selectOdsWhiteEmbryoInventoryByID(String ID);

	/**
	 * 查询白胚盘点单列表
	 * 
	 * @param odsWhiteEmbryoInventory 白胚盘点单
	 * @return 白胚盘点单集合
	 */
	public List<OdsWhiteEmbryoInventory> selectOdsWhiteEmbryoInventoryList(OdsWhiteEmbryoInventory odsWhiteEmbryoInventory);

	/**
	 * 新增白胚盘点单
	 * 
	 * @param odsWhiteEmbryoInventory 白胚盘点单
	 * @return 结果
	 */
	public int insertOdsWhiteEmbryoInventory(OdsWhiteEmbryoInventory odsWhiteEmbryoInventory);

	/**
	 * 修改白胚盘点单
	 * 
	 * @param odsWhiteEmbryoInventory 白胚盘点单
	 * @return 结果
	 */
	public int updateOdsWhiteEmbryoInventory(OdsWhiteEmbryoInventory odsWhiteEmbryoInventory);

	/**
	 * 批量删除白胚盘点单
	 * 
	 * @param IDs 需要删除的白胚盘点单主键集合
	 * @return 结果
	 */
	public int deleteOdsWhiteEmbryoInventoryByIDs(String[] IDs);

	/**
	 * 删除白胚盘点单信息
	 * 
	 * @param ID 白胚盘点单主键
	 * @return 结果
	 */
	public int deleteOdsWhiteEmbryoInventoryByID(String ID);
}
